# frozen_string_literal: true

module Qualys
  # Qualys vulnerabilities from a report xml
  class Vulnerability
    attr_accessor :qid, :type, :port, :service, :protocol, :ssl, :result,
                  :first_found, :last_found, :times_found, :status, :details,
                  :cve_code_list, :title, :severity, :category, :threat, :impact,
                  :solution, :pci_flag, :correlation, :vendor_reference_list, :last_update,
                  :url

    def initialize(vuln, glossary)
      parse_vuln vuln

      match_details glossary

      parse_cve if @details['CVE_ID_LIST']
      parse_details
      # gives the url to the qualys knowledge base for this vulnerabitlty
      parse_url
    end

    def to_s
      "#{qid}, #{title}, severity : #{severity}, cves: #{cve_code_list&.join(', ') || 'no cve'}"
    end

    private

    def parse_cve
      cve_xlm_array = if @details['CVE_ID_LIST']['CVE_ID'].is_a?(Array)
                        @details['CVE_ID_LIST']['CVE_ID']
                      else
                        [@details['CVE_ID_LIST']['CVE_ID']]
                      end
      @cve_code_list = cve_xlm_array.map { |cve| cve['ID'] }
    end

    # this methods finds the details for this qid in the report's glossary
    def match_details(glossary)
      @details = glossary.select { |detail| detail['id'] == @qid }[0]
    end

    def parse_details
      @title = @details['TITLE']
      @severity = @details['SEVERITY']
      @category = @details['CATEGORY']
      @threat = @details['THREAT']
      @impact = @details['IMPACT']
      @solution = @details['SOLUTION']
      @pci_flag = @details['PCI_FLAG']
      @correlation = @details['CORRELATION']
      @vendor_reference_list = @details['VENDOR_REFERENCE_LIST']
      @last_update = @details['BUGTRAQ_ID_LIST']
    end

    def parse_url
      @url = 'https://qualysguard.qualys.eu/fo/common/vuln_info.php?id=' + @qid[4..-1]
    end

    def parse_vuln(vuln)
      @qid = vuln['QID']['id']
      @type = vuln['TYPE']
      @port = vuln['PORT']
      @service = vuln['SERVICE']
      @protocol = vuln['PROTOCOL']
      @ssl = vuln['SSL']
      @result = vuln['RESULT']
      @first_found = vuln['FIRST_FOUND']
      @last_found = vuln['LAST_FOUND']
      @times_found = vuln['TIMES_FOUND']
      @status = vuln['VULN_STATUS']
    end
  end
end
